@@ -2,7 +2,7 @@ package autobox::Closure::Attributes;
 use strict;
 use warnings;
 use base 'autobox';
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub import {
     shift->SUPER::import(CODE => 'autobox::Closure::Attributes::Methods');
@@ -45,22 +45,24 @@ autobox::Closure::Attributes - closures are objects are closures
 =head1 SYNOPSIS
 
     use autobox::Closure::Attributes;
+    use feature 'say';
 
     sub accgen {
         my $n = shift;
-        return sub { $n += shift || 1 }
+        return sub { ++$n }
     }
 
     my $from_3 = accgen(3);
 
-    $from_3->n     # 3
-    $from_3->()    # 4
-    $from_3->n     # 4
-    $from_3->n(10) # 10
-    $from_3->()    # 11
-    $from_3->m     # "CODE(0xDEADBEEF) does not close over $m"
+    say $from_3->n;     # 3
+    say $from_3->();    # 4
+    say $from_3->n;     # 4
+    say $from_3->n(10); # 10
+    say $from_3->();    # 11
+    say $from_3->();    # 12
+    say $from_3->m;     # "CODE(0xDEADBEEF) does not close over $m"
 
-=head1 WHAT?
+=head1 DESCRIPTION
 
 The venerable master Qc Na was walking with his student, Anton. Hoping to
 prompt the master into a discussion, Anton said "Master, I have heard that
@@ -80,7 +82,7 @@ are truly a poor man's closures." Qc Na responded by hitting Anton with his
 stick, saying "When will you learn? Closures are a poor man's objects." At that
 moment, Anton became enlightened.
 
-=head1 DESCRIPTION
+=head1 IMPLEMENTATION
 
 This module uses powerful tools to give your closures accessors for each of the
 closed-over variables. You can get I<and> set them.
@@ -142,7 +144,7 @@ Shawn M Moore, C<sartak@gmail.com>
 
 L<autobox>, L<PadWalker>
 
-The L</WHAT?> section is from Anton van Straaten: L<http://people.csail.mit.edu/gregs/ll1-discuss-archive-html/msg03277.html>
+The L</DESCRIPTION> section is from Anton van Straaten: L<http://people.csail.mit.edu/gregs/ll1-discuss-archive-html/msg03277.html>
 
 =head1 BUGS
 
@@ -157,7 +159,7 @@ This happens because Perl optimizes away the capturing of unused variables.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 Shawn M Moore.
+Copyright 2007-2016 Shawn M Moore.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
